@@ -8,12 +8,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARVIEWS_JOURNALFRAME_H
-#define CALENDARVIEWS_JOURNALFRAME_H
+#pragma once
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
-#include <Item>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/IncidenceChanger>
+#include <Akonadi/Item>
 
 #include <QDate>
 #include <QFrame>
@@ -62,7 +61,7 @@ public Q_SLOTS:
         mChanger = changer;
     }
 
-    void setDate(const QDate &date);
+    void setDate(QDate date);
 
 Q_SIGNALS:
     void printJournal(const KCalendarCore::Journal::Ptr &, bool preview);
@@ -86,19 +85,19 @@ private:
     Akonadi::IncidenceChanger *mChanger = nullptr;
 };
 
-class JournalDateView : public QFrame
+class JournalDateView : public QWidget
 {
     Q_OBJECT
 public:
     using List = QList<JournalDateView *>;
 
     JournalDateView(const Akonadi::ETMCalendar::Ptr &, QWidget *parent);
-    ~JournalDateView();
+    ~JournalDateView() override;
 
     void addJournal(const Akonadi::Item &journal);
     Akonadi::Item::List journals() const;
 
-    void setDate(const QDate &date);
+    void setDate(QDate date);
     QDate date() const
     {
         return mDate;
@@ -131,4 +130,3 @@ private:
 };
 }
 
-#endif
