@@ -16,6 +16,9 @@
 #include <QEvent>
 #include <QHeaderView>
 #include <QMouseEvent>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 TodoViewView::TodoViewView(QWidget *parent)
     : QTreeView(parent)
@@ -23,7 +26,7 @@ TodoViewView::TodoViewView(QWidget *parent)
     header()->installEventFilter(this);
     setAlternatingRowColors(true);
     connect(&mExpandTimer, &QTimer::timeout, this, &TodoViewView::expandParent);
-    mExpandTimer.setInterval(1000);
+    mExpandTimer.setInterval(1s);
     header()->setStretchLastSection(false);
 }
 
@@ -52,7 +55,7 @@ bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
             connect(mHeaderPopup, &QMenu::triggered, this, &TodoViewView::toggleColumnHidden);
         }
 
-        for (QAction *action : qAsConst(mColumnActions)) {
+        for (QAction *action : std::as_const(mColumnActions)) {
             int column = action->data().toInt();
             action->setChecked(!isColumnHidden(column));
         }
@@ -151,7 +154,7 @@ QModelIndex TodoViewView::moveCursor(CursorAction cursorAction, Qt::KeyboardModi
 QModelIndex TodoViewView::getNextEditableIndex(const QModelIndex &cur, int inc)
 {
     if (!cur.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     QModelIndex tmp;
